/* You can add global styles to this file, and also import other style files */

//@import '~bootstrap/dist/less/bootstrap.less';
//@import '~bootstrap/dist/css/bootstrap-theme.min';
//@import '~@synerty/peek-theme/scss/layout.web';


@import '~@synerty/peek-theme/scss/variables.web';

//sizes
$general_border: 1.3px;
$general_border_radius: 4px;
$general_button_padding: 6px;
$general_button_min_width: 40px;
$general_line_height: 0.3;

$general_width_1: 60px;
$general_width_2: 125px;

$general_font_size_1: 8px;
$general_font_size_2: 10px;
$general_font_size_3: 12px;
$general_font_size_4: 14px;
$general_font_size_5: 14px;
$general_font_size_6: 24px;
$general_font_size_7: 32px;

$general_height_1: 32px;
$general_height_2: 40px;
$general_height_3: 60px;

$general_padding_1: 8px;
$general_padding_2: 16px;
$general_padding_3: 20px;
$general_padding_4: 32px;
$general_padding_5: 64px;

$general_margin_1: 8px;
$general_margin_2: 10px;
$general_margin_3: 16px;
$general_margin_4: 32px;

@import '~@synerty/peek-theme/scss/mixins.web';

*:focus {outline:none!important;}

//peek screens
@import '~@synerty/peek-theme/scss/style/_title_bar';
@import '~@synerty/peek-theme/scss/style/_home_screen';

//plugin screens
@import '~@synerty/peek-theme/scss/style/_plugin_inbox';
@import '~@synerty/peek-theme/scss/style/_plugin_chat';

//generic sections
@import '~@synerty/peek-theme/scss/style/_navigation_section';
@import '~@synerty/peek-theme/scss/style/_tabs_section';
@import '~@synerty/peek-theme/scss/style/_mobile_dialog_section';
@import '~@synerty/peek-theme/scss/style/_information_section';
@import '~@synerty/peek-theme/scss/style/_details_section';
@import '~@synerty/peek-theme/scss/style/_tables_section';

@import '~@synerty/peek-theme/scss/style/_general';

body,
html{
  font-size: $general_font_size_3;
  color: $font_colour_information;
  //height: 100%;
  font-family: $fonts_special;
}

hr {
    margin-top: unset;
    margin-bottom: unset;
}

.navigation-information{
  border-bottom: $general_border solid darken($grey,20%);
  //margin-bottom: $general_padding;
}

.form-group{
  color: $black;
}

